@@ -1,4 +1,6 @@
 import io
+import random
+
 from pythonwhat.check_syntax import Ex
 from pythonwhat.State import State
 from pythonwhat.Reporter import Reporter
@@ -16,21 +18,22 @@ class StubShell(object):
 
 class StubProcess(object):
 
-    def __init__(self, init_code = None):
+    def __init__(self, init_code = None, pid = None):
         self.shell = StubShell(init_code)
+        self._identity = (pid,) if pid else (random.randint(0, 1e12),)
 
     def executeTask(self, task):
         return task(self.shell)
 
-def setup_state(stu_code = "", sol_code = "", pec = ""):
+def setup_state(stu_code = "", sol_code = "", pec = "", pid = None):
 
     stu_output = io.StringIO()
     with redirect_stdout(stu_output):
-        stu_process = StubProcess(init_code =  "%s\n%s" % (pec, stu_code))
+        stu_process = StubProcess("%s\n%s" % (pec, stu_code), pid)
 
     sol_output = io.StringIO()
     with redirect_stdout(sol_output):
-        sol_process = StubProcess(init_code =  "%s\n%s" % (pec, sol_code))
+        sol_process = StubProcess("%s\n%s" % (pec, sol_code), pid)
 
     rep = Reporter()
     Reporter.active_reporter = rep
